@@ -1,7 +1,7 @@
 use crate::abi::{OutputAbi, TypeAbi, TypeDescriptionContainer};
 use crate::api::SendApi;
 use crate::io::EndpointResult;
-use crate::types::{Address, BoxedBytes};
+use crate::types::{Address, BoxedBytes, TokenIdentifier};
 use alloc::string::String;
 use alloc::vec::Vec;
 
@@ -24,9 +24,9 @@ where
 
 	#[inline]
 	fn finish<FA>(&self, _api: FA) {
-		self.api.direct_esdt_via_async_call(
+		self.api.transfer_esdt_via_async_call(
 			&self.to,
-			&self.token_name.as_slice(),
+			&TokenIdentifier::from(self.token_name.clone()),
 			&self.amount,
 			self.data.as_slice(),
 		);
