@@ -24,8 +24,17 @@ where
 
 	#[inline]
 	fn finish<FA>(&self, _api: FA) {
-		self.api
-			.direct_via_async_call(&self.to, &self.token, &self.amount, self.data.as_slice());
+		if self.token.is_egld() {
+			self.api
+				.direct_egld(&self.to, &self.amount, self.data.as_slice());
+		} else {
+			self.api.transfer_esdt_via_async_call(
+				&self.to,
+				&self.token,
+				&self.amount,
+				self.data.as_slice(),
+			);
+		}
 	}
 }
 
